/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
 *
*/

#ifndef __G_FILE_MONITOR_H__
#define __G_FILE_MONITOR_H__

#include <glib.h>
#include <glib-object.h>

typedef struct _GFileMonitor       GFileMonitor;
typedef struct _GFileMonitorClass  GFileMonitorClass;

#define G_TYPE_FILE_MONITOR\
	(g_file_monitor_get_type ())
#define G_FILE_MONITOR(obj)\
	(G_TYPE_CHECK_INSTANCE_CAST ((obj), G_TYPE_FILE_MONITOR, GFileMonitor))
#define G_FILE_MONITOR_CLASS(obj)\
	(G_TYPE_CHECK_CLASS_CAST ((obj), G_FILE_MONITOR,  GFileMonitorClass))
#define G_IS_FILE_MONITOR(obj)\
	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_TYPE_FILE_MONITOR))
#define G_IS_FILE_MONITOR_CLASS(obj)\
	(G_TYPE_CHECK_CLASS_TYPE ((obj), G_TYPE_FILE_MONITOR))
#define G_FILE_MONITOR_GET_CLASS\
	(G_TYPE_INSTANCE_GET_CLASS ((obj), G_TYPE_FILE_MONITOR, GFileMonitorClass))

struct _GFileMonitor {
	GObject   parent_instance;
	
	char      *file_path;
};

struct _GFileMonitorClass {
	GObjectClass parent_class;
	
	void (* file_changed) (GFileMonitor *monitor);
};

/**
 * Creates and returns a new GFileMonitor object.
 *
 * @return The GFileMonitor object created.
 */
GFileMonitor* g_file_monitor_new (const char *file_path);

/**
 * Destroys and frees GFileMonitor.
 *
 * @param monitor The GFileMonitor.
 */
void g_file_monitor_fini (GFileMonitor *monitor);

#endif
