/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_APP_CHOOSER_H__
#define __KIBA_APP_CHOOSER_H__

#include <gtk/gtk.h>
#include <kiba-icon-view-win.h>

G_BEGIN_DECLS

#define KIBA_TYPE_APP_CHOOSER           (kiba_app_chooser_get_type ())
#define KIBA_APP_CHOOSER(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_APP_CHOOSER, KibaAppChooser))
#define KIBA_APP_CHOOSER_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_APP_CHOOSER,  KibaAppChooserClass))
#define KIBA_IS_APP_CHOOSER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_APP_CHOOSER))
#define KIBA_IS_APP_CHOOSER_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_APP_CHOOSER))
#define KIBA_APP_CHOOSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_APP_CHOOSER, KibaAppChooserClass))

typedef struct _KibaAppChooser       KibaAppChooser;
typedef struct _KibaAppChooserClass  KibaAppChooserClass;

typedef enum {
	KIBA_APP_SECTION_ALL = 0,
	KIBA_APP_SECTION_SYSTEM,
	KIBA_APP_SECTION_SETTINGS,
	KIBA_APP_SECTION_OFFICE,
	KIBA_APP_SECTION_GRAPHICS,
	KIBA_APP_SECTION_AUDIO_VIDEO,
	KIBA_APP_SECTION_NETWORK,
	KIBA_APP_SECTION_GAMES,
	KIBA_APP_SECTION_DEVELOPMENT,
	KIBA_APP_SECTION_TOOLS,
	KIBA_APP_SECTION_LAST
}KibaAppChooserSection;

typedef struct {
	KibaAppChooser        *chooser;
	KibaAppChooserSection  section;
	gboolean               added;
	GtkWidget             *image;
	char                  *uri;
	char                  *name;
	char                  *description;
}KibaAppChooserApp;

struct _KibaAppChooser {
	GObjectClass   parent_instance;
	
	KibaIconViewWin *view_win;
	GtkWidget       *entry;
	GtkWidget       *combobox;
	GtkWidget       *name_label;
	GtkWidget       *description_label;
	GList           *apps;
};

struct _KibaAppChooserClass {
	GObjectClass  parent_class;
	
	void (* app_activate) (KibaAppChooser *chooser,
			       const char     *desktop);
};

/**
 * Creates and returns a KibaAppChooser Instance.
 *
 * @return The KibaAppChooser Instance created.
 */
KibaAppChooser* kiba_app_chooser_new (const char *app_path);

G_END_DECLS

#endif
