
/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_CAIRO_UTILS_H__
#define __KIBA_CAIRO_UTILS_H__

#include <cairo.h>
#include <kiba-types.h>

G_BEGIN_DECLS

typedef struct _CairoSurfaceData CairoSurfaceData;

typedef void (*CairoSurfaceFunc) (cairo_t*, cairo_surface_t*, gint, gint, void*);

struct _CairoSurfaceData {
	cairo_surface_t *surface;
	gint             width;
	gint             height;
};

GdkPixbuf* cairo_get_pixbuf_from_surface (cairo_surface_t *surface,
					  gint             width,
					  gint             height);

void cairo_update_surface_at_size (cairo_t          *cr,
				   cairo_surface_t **surface,
				   gint              width,
				   gint              height,
				   CairoSurfaceFunc  draw_function,
				   void             *data);

void cairo_update_surface (cairo_t          *cr,
			   CairoSurfaceData *surface_data,
			   CairoSurfaceFunc  draw_function,
			   void             *data);

cairo_t* cairo_create_pixmap_context (int         width,
				      int         height,
				      GdkPixmap **pixmap,
				      GdkGC     **gc);

cairo_surface_t* cairo_get_image_surface_from_puc_data (unsigned char **puc_data,
							int             width,
							int             height);

cairo_t* cairo_get_context_from_puc_data (unsigned char **puc_data,
					  int             width,
					  int             height);

unsigned char* cairo_create_puc_data (int width,
				      int height);

void cairo_paint_with_prelight (cairo_t *cr,
				double   alpha,
				int      width,
				int      height);

void cairo_rotate_centered (cairo_t *cr,
			    double   angle,
			    int      x,
			    int      y);

void cairo_update_pango_layout (const char   *text,
			        const char   *description,
			        cairo_t      *cr,
			        PangoLayout **layout);

/**
 * Get Pattern for PNG File.
 *
 * @param cr The Cairo Context.
 * @param png_file The PNG File.
 * @param rotate.
 * @return The cairo_pattern_t created.
 */
cairo_pattern_t* cairo_get_png_pattern (const char *file);

cairo_pattern_t* cairo_get_gradient_pattern (int       x0,
					     int       y0,
					     int       x1,
					     int       y1,
					     KibaRGBA  rgba_1,
					     KibaRGBA  rgba_2,
					     KibaRGBA  rgba_3);

cairo_pattern_t* cairo_get_radial_pattern (int        x0,
					   int        y0,
					   int        x1,
					   int        y1,
					   KibaRGBA   rgba_1,
					   KibaRGBA   rgba_2,
					   double     step_size);

cairo_pattern_t* cairo_get_linear_pattern (int        x0,
					   int        y0,
					   int        x1,
					   int        y1,
					   KibaRGBA   rgba_1,
					   KibaRGBA   rgba_2,
					   double     affection,
					   double     step_size);

void cairo_paint_shape (cairo_t               *cr,
			const KibaLayoutData  *d,
			KibaCornerShape        topleft_corner,
			KibaCornerShape        topright_corner,
			KibaCornerShape        bottomleft_corner,
			KibaCornerShape        bottomright_corner,
			gboolean               draw_all_border,
			double                 x0,
			double                 y0,
			double                 x1,
			double                 y1,
			double                 radius,
			double                 border_width);

/**
 * Set Cairo Context RGBA from string.
 *
 * @param cr The Cairo Context.
 * @param alpha_factor Alpha Factor.
 * @param rgba The RGBA String (#FFFFFFFF for 100% opacity and white color).
 */
void cairo_set_source_rgba_from_string (cairo_t    *cr,
					double      alpha_factor,
					const char *rgba);

G_END_DECLS

#endif
