/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_DEBUG_H
#define __KIBA_DEBUG_H

#include <glib.h>

G_BEGIN_DECLS

#define DEBUG_INFO __FILE__, __LINE__

/**
 * Debug levels.
 */
enum {
	KIBA_DEBUG_MISC = 0, /**< General chatter.               */
	KIBA_DEBUG_INFO,     /**< General operation Information. */
	KIBA_DEBUG_WARNING,  /**< Warnings.                      */
	KIBA_DEBUG_ERROR,    /**< Errors.                        */
	KIBA_DEBUG_FATAL     /**< Fatal errors.                  */
};

/**
 * Initiall/Enable Debugging.
 */
void kiba_debug_init (void);

/**
 * Get wether Debugging is enabled.
 *
 * @return @c TRUE if debugging is enabled, otherwise
 *         @c FALSE.
 */
gboolean kiba_debug_is_enabled();

/**
 * Print a Debug Message.
 *
 * @param level level of Debugging.
 * @param file __FILE__ value.
 * @param line __LINE__ value.
 * @param format
 * @param ...
 */
void kiba_debug_message (int          level,
			 const char  *file,
			 signed int   line,
			 const char *format,
			 ...);

/**
 * Print a Debug Message with KIBA_DEBUG_INFO level.
 *
 * @param file __FILE__ value.
 * @param line __LINE__ value.
 * @param format
 * @param ...
 */
void kiba_debug_message_info (const char *file,
			      signed int  line,
			      const char *format,
			      ...);

/**
 * Print a Debug Message with KIBA_DEBUG_MISC level.
 *
 * @param file __FILE__ value.
 * @param line __LINE__ value.
 * @param format
 * @param ...
 */
void kiba_debug_message_misc (const char *file,
			      signed int  line,
			      const char *format,
			      ...);

/**
 * Print a Debug Message with KIBA_DEBUG_ERROR level.
 *
 * @param file __FILE__ value.
 * @param line __LINE__ value.
 * @param format
 * @param ...
 */
void kiba_debug_message_error (const char *file,
			       signed int  line,
			       const char *format,
			       ...);

/**
 * Print a Debug Message with KIBA_DEBUG_FATAL level.
 *
 * @param file __FILE__ value.
 * @param line __LINE__ value.
 * @param format
 * @param ...
 */
void kiba_debug_message_fatal (const char *file,
			       signed int  line,
			       const char *format,
			       ...);

G_END_DECLS

#endif
