/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __DND_ARROW_H
#define __DND_ARROW_H

#include <glib.h>
#include <cairo.h>

#include <kiba-types.h>
#include <kiba-cairo-utils.h>

G_BEGIN_DECLS

typedef struct _KibaDndArrow         KibaDndArrow;
typedef struct _KibaDndArrowClass    KibaDndArrowClass;

#define KIBA_TYPE_DND_ARROW           (kiba_dnd_arrow_get_type ())
#define KIBA_DND_ARROW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_DND_ARROW, KibaDndArrow))
#define KIBA_DND_ARROW_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_DND_ARROW,  KibaDndArrowClass))
#define KIBA_IS_DND_ARROW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_DND_ARROW))
#define KIBA_IS_DND_ARROW_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_DND_ARROW))
#define KIBA_DND_ARROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_DND_ARROW, KibaDndArrowClass))

enum {
	KIBA_DND_ARROW_DRAWABLE = 0
};

struct _KibaDndArrow {
	GObject          parent;
	GtkWidget       *win;
	
	cairo_surface_t *surface;
	GdkRectangle     area;
};

struct _KibaDndArrowClass {
	GObjectClass parent_class;
};

/**
 * Create a KibaDndArrow Instance.
 *
 * @return The KibaDndArrow Instance created.
 */
KibaDndArrow* kiba_dnd_arrow_new (GtkWidget *win);

void kiba_dnd_arrow_set_position (KibaDndArrow *arrow,
				  gint          x,
				  gint          y);

/**
 * Draw the bubble Surface-Buffer to a Drawing context.
 *
 * @param cr The Drawing Context.
 */
void kiba_dnd_arrow_draw (KibaDndArrow         *arrow,
			  const KibaLayoutData *d,
			  cairo_t              *cr);

gboolean kiba_dnd_arrow_is_shown (KibaDndArrow *arrow);

/**
 * Free allocated memory for a KibaDndArrow Instance.
 *
 * @param bubble The KibaSettings Instance.
 */
void kiba_dnd_arrow_destroy (KibaDndArrow *arrow);

G_END_DECLS

#endif /* _DND_ARROW_H */
