/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_PLUGIN_H__
#define __KIBA_PLUGIN_H__

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <glib.h>

#include <kiba-prefs.h>

G_BEGIN_DECLS

typedef struct _KibaPlugin       KibaPlugin;
typedef struct _KibaPluginClass  KibaPluginClass;
typedef struct _KibaPluginVtable KibaPluginVtable;

#define KIBA_TYPE_PLUGIN           (kiba_plugin_get_type ())
#define KIBA_PLUGIN(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_PLUGIN, KibaPlugin))
#define KIBA_PLUGIN_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_PLUGIN,  KibaPluginClass))
#define KIBA_IS_PLUGIN(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_PLUGIN))
#define KIBA_IS_PLUGIN_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_PLUGIN))
#define KIBA_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_PLUGIN, KibaPluginClass))

/**
 * Handles the initialization of modules.
 */
#define KIBA_INIT_PLUGIN(vtable, plugin_settings) \
	gboolean kiba_init_plugin(KibaPlugin *plugin);\
	gboolean kiba_init_plugin(KibaPlugin *plugin) { \
		plugin->vtable = &(vtable); \
		plugin->options = plugin_settings; \
		plugin->option_elements = G_N_ELEMENTS (plugin_settings); \
		return kiba_plugin_register (plugin); \
	}

/**
 * A Plugin VTable.
 */
struct _KibaPluginVtable {
	const char *name;         /* plugin id/name        */
	const char *summary;      /* plugin summary        */
	const char *description;  /* plugin description    */
	
	const char *author;       /* plugin author         */
	const char *homepage;     /* plugin homepage       */
	
	gboolean (*load) (KibaPlugin *plugin); /* plugin load function */
	void  (*unload) (KibaPlugin *plugin);  /* plugin unload function */
};

/**
 * A Plugin Handle.
 */
struct _KibaPlugin {
	GTypeModule        parent_instance;
	char              *lib_path;
	
	KibaPluginVtable  *vtable;
	
	gboolean           enabled;             /* represents $(plugin_name)_enable from Prefs */
	gboolean           loaded;              /* TRUE if Plugin is loaded */
	PrefMember        *options;             /* array of all plugin options */
	gint               option_elements;     /* num of array member */
};

struct _KibaPluginClass {
	GTypeModuleClass parent_class;
	
	void (* unloaded) (KibaPlugin *plugin);
	void (* loaded)   (KibaPlugin *plugin);
};

/**
 * Creates and returns a new KibaPlugin widget.
 *
 * @param library_path The path to the Plugin Library.
 * @return The KibaPlugin widget created.
 */
KibaPlugin* kiba_plugin_new (char *library_path);

/**
 * Launch Function for all loaded KibaPlugin's.
 *
 * @param for_all_func The Function to launch for every KibaPlugin.
 * @param data The UserData for the Function.
 */
void kiba_plugin_for_all (GFunc  for_all_func,
			  void  *data);

/**
 * Get loaded KibaPlugin's.
 *
 * @return The loaded KibaPlugin's.
 */
GList* kiba_plugin_get_loaded (void);

/**
 * Get a Pointer to a loaded KibaPlugin.
 *
 * @param name The ID of the Plugin to search for.
 * @return The found KibaPlugin or NULL if no plugin with that ID was loaded.
 */
KibaPlugin* kiba_plugin_get_for_id (const char *id);

void kiba_plugins_free ();

G_END_DECLS

#endif
