/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_PROGRESS_H__
#define __KIBA_PROGRESS_H__

#include <glib.h>
#include <cairo.h>

#include <kiba-bubble.h>

G_BEGIN_DECLS

typedef struct _KibaProgress         KibaProgress;
typedef struct _KibaProgressObject   KibaProgressObject;
typedef struct _KibaProgressClass    KibaProgressClass;

#define KIBA_TYPE_PROGRESS           (kiba_progress_get_type ())
#define KIBA_PROGRESS(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_PROGRESS, KibaProgress))
#define KIBA_PROGRESS_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_PROGRESS,  KibaProgressClass))
#define KIBA_IS_PROGRESS(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_PROGRESS))
#define KIBA_IS_PROGRESS_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_PROGRESS))
#define KIBA_PROGRESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_PROGRESS, KibaProgressClass))

enum {
	KIBA_PROGRESS_DRAWABLE = 0
};

typedef struct {
	KibaRGBA rgba;
	KibaRGBA bg_rgba;
}KibaProgressStyle;

struct _KibaProgressObject {
	KibaProgress      *progress;
	KibaBubbleObject  *bubble;
	
	GdkRectangle       area;
	
	gboolean           bubble_message;
	gint               value;         /* current value of the process */
	gint               current_value;
	gint               value_change_id;
};

struct _KibaProgress {
	GObject            parent;
	GtkWidget         *win;
	
	gint               flags;
	KibaProgressStyle  style;
	
	cairo_surface_t   *surface;
};

struct _KibaProgressClass {
	GObjectClass parent_class;
};

/**
 * Create a KibaProgress Instance.
 *
 * @return The KibaProgress Instance created.
 */
KibaProgress* kiba_progress_new (GtkWidget *win);

void kiba_progress_set_style (KibaProgress      *progress,
			      KibaProgressStyle  style);

void kiba_progress_set_flag (KibaProgress *progress,
			     gint          flag);

void kiba_progress_unset_flag (KibaProgress *progress,
			       gint          flag);

/**
 * Draw the progress Surface-Buffer to a Drawing context.
 *
 * @param progress The KibaProgress Instance.
 * @param cr The Drawing Context.
 */
void kiba_progress_draw (KibaProgress *progress,
			 cairo_t      *cr);

/**
 * Free allocated memory for a KibaProgress Instance.
 *
 * @param progress The KibaSettings Instance.
 */
void kiba_progress_destroy (KibaProgress *progress);

KibaProgressObject* kiba_progress_object_add (KibaBubbleObject *bubble);

void kiba_progress_object_remove (KibaProgressObject *object);

/**
 * Return if a progress for a KibaProgress Instance is running.
 *
 * @param progress The KibaProgress Instance.
 * @return @c TRUE  if a progress, started with kiba_progress_start, is running, otherwise
 *	   @c FALSE is returned.
 */
gboolean kiba_progress_object_is_running (KibaProgressObject *object);

/**
 * Set progress info for a KibaProgress Instance.
 *
 * @param progress The KibaProgress Instance.
 * @param value The new progress value (must be <= 100).
 * @param message The new Progress message or NULL.
 */
void kiba_progress_object_set_info (KibaProgressObject *object,
				    gint                value,
				    const char         *message);

G_END_DECLS

#endif
