/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-kiba.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-kiba.org>
*/

#ifndef __KIBA_TITLE_H__
#define __KIBA_TITLE_H__

#include <gdk/gdk.h>
#include <cairo.h>

#include <kiba-types.h>
#include <kiba-cairo-utils.h>

G_BEGIN_DECLS

#define KIBA_TYPE_TITLE           (kiba_title_get_type ())
#define KIBA_TITLE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TITLE, KibaTitle))
#define KIBA_TITLE_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TITLE,  KibaTitleClass))
#define KIBA_IS_TITLE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TITLE))
#define KIBA_IS_TITLE_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TITLE))
#define KIBA_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TITLE, KibaTitleClass))

typedef struct _KibaTitle        KibaTitle;
typedef struct _KibaTitleObject  KibaTitleObject;
typedef struct _KibaTitleClass   KibaTitleClass;

enum {
	TITLE_HIDING = 0,
	TITLE_HIDDEN,
	TITLE_SHOWING,
	TITLE_SHOWN
};

typedef struct {
	union {
		KibaBackgroundStyle style;
		char               *file;
	}background;
	
	KibaCornerShape border_style;
	double          border_width;
	double          bg_affection;
	double          bg_step_size;
	KibaRGBA        rgba;
	KibaRGBA        shadow_rgba;
	KibaRGBA        border_rgba;
	KibaRGBA        bg_rgba_1;
	KibaRGBA        bg_rgba_2;
	KibaRGBA        bg_rgba_3;
}KibaTitleStyle;

enum {
	KIBA_TITLE_SCALING = 0,
	KIBA_TITLE_DRAWABLE
};

struct _KibaTitleObject {
	KibaTitle        *title;
	
	GtkWidget        *widget;
	
	CairoSurfaceData  surface_data;
	PangoLayout      *pango_layout;
	char             *text;
};

struct _KibaTitle {
	GObject           parent;
	
	GtkWidget        *win;
	
	gint              flags;
	gint              state;
	KibaTitleStyle    style;
	char             *font;
	gint              hide_delay;
};

struct _KibaTitleClass {
	GObjectClass     parent_class;
};

/**
 * Creates and returns a new KibaTitle.
 *
 * @return The KibaTitle object created.
 */
KibaTitle* kiba_title_new (GtkWidget *win);

gboolean kiba_title_is_shown (KibaTitle *title);

void kiba_title_set_style (KibaTitle      *title,
			   KibaTitleStyle  style);

void kiba_title_set_flag (KibaTitle *title,
			  gint       flag);

void kiba_title_unset_flag (KibaTitle *title,
			    gint       flag);

void kiba_title_set_font (KibaTitle  *title,
			  char       *font);

void kiba_title_draw (KibaTitle            *title,
		      const KibaLayoutData *d,
		      cairo_t              *cr);

void kiba_title_destroy (KibaTitle *title);

KibaTitleObject* kiba_title_object_add (GtkWidget *widget);

void kiba_title_object_show (KibaTitleObject *object);

void kiba_title_object_hide (KibaTitleObject *object);

gboolean kiba_title_object_is_shown (KibaTitleObject *object);

void kiba_title_object_set_text (KibaTitleObject *object,
				 const char *text);

char* kiba_title_object_get_text (KibaTitleObject *object);

void kiba_title_object_remove (KibaTitleObject *object);

G_END_DECLS

#endif
