/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_WIN_H__
#define __KIBA_WIN_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <cairo.h>

#include <kiba-dock.h>
#include <kiba-title.h>
#include <kiba-dnd-arrow.h>
#include <kiba-triangle.h>
#include <kiba-bubble.h>
#include <kiba-progress.h>
#include <kiba-types.h>

G_BEGIN_DECLS

#define KIBA_TYPE_WIN           (kiba_win_get_type ())
#define KIBA_WIN(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_WIN, KibaWin))
#define KIBA_WIN_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_WIN,  KibaWinClass))
#define KIBA_IS_WIN(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_WIN))
#define KIBA_IS_WIN_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_WIN))
#define KIBA_WIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_WIN, KibaWinClass))

#define KIBA_WIN_CHILD(win)     gtk_bin_get_child(GTK_BIN(win))

#define KIBA_WIN_IS_ABOVE(win)  GET_FLAG(win->probs, KIBA_WIN_ABOVE)
#define KIBA_WIN_IS_BELOW(win)  GET_FLAG(win->probs, KIBA_WIN_BELOW)
#define KIBA_WIN_IS_BLURRY(win) GET_FLAG(win->probs, KIBA_WIN_BLUR)

typedef struct _KibaWin       KibaWin;
typedef struct _KibaWinClass  KibaWinClass;

/**
 * Callback function to handle Drag and Drag receive requests
 *
 * @param GdkDragContext A Drag and Drop Context.
 * @param char The Group.
 * @param gpointer User Data.
 * @return TRUE on succes, no further processing is needed, otherwhise FALSE
 */
typedef gboolean (*KibaDragReceiveFunc) (GdkDragContext*, const char*, gpointer);

typedef enum {
	KIBA_WIN_BELOW = 0,
	KIBA_WIN_ABOVE,
	KIBA_WIN_BLUR,
	KIBA_WIN_DND_ARROW
}KibaWinProbs;

struct _KibaWin {
	GtkWindow       window;
	KibaWinProbs    probs;
	
	KibaTitle      *title;
	KibaTriangle   *triangle;
	KibaBubble     *bubble;
	KibaProgress   *progress;
	KibaDndArrow   *arrow;
};

struct _KibaWinClass {
	GtkWindowClass  parent_class;
	
	void (* dock_hidden) (KibaWin  *win,
			      KibaDock *dock);
	void (* dock_unhidden) (KibaWin  *win,
			        KibaDock *dock);
};

/**
 * Creates and returns a KibaWin Instance.
 *
 * @return The KibaWin Instance created.
 */
GtkWidget* kiba_win_new (void);

KibaWin* kiba_win_get_default ();

cairo_t* kiba_win_cairo_create (KibaWin *win);

/**
 * Invalidate area on widget's window, and queue it for drawing
 */
void kiba_win_invalidate_area (GtkWidget   *widget,
			       GdkRectangle area);

void kiba_win_set_flag (KibaWin     *win,
			KibaWinProbs prob);

void kiba_win_unset_flag (KibaWin     *win,
			  KibaWinProbs prob);

void kiba_win_add_drag_func (KibaWin            *win,
			     KibaDragReceiveFunc func,
			     gpointer            user_data);

void kiba_win_remove_drag_func (KibaWin            *win,
				KibaDragReceiveFunc func);

void kiba_win_resize_children (GtkWidget *widget);

/**
 * Hide the dock and call gtk_main_quit()
 */
void kiba_win_quit (GtkWidget *widget);

G_END_DECLS

#endif
