/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author :	Daniel Bessler <danielb@kiba-dock.org>
 *
*/

#ifndef __KIBA_WINDOW_H__
#define __KIBA_WINDOW_H__

#include <glib.h>
#include <gdk/gdk.h>
#include <X11/Xlib.h>

G_BEGIN_DECLS

typedef struct _KibaWindow      KibaWindow;
typedef struct _KibaWindowClass KibaWindowClass;

#define KIBA_TYPE_WINDOW           (kiba_window_get_type ())
#define KIBA_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_WINDOW, KibaWindow))
#define KIBA_WINDOW_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_WINDOW,  KibaWindowClass))
#define KIBA_IS_WINDOW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_WINDOW))
#define KIBA_IS_WINDOW_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_WINDOW))
#define KIBA_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_WINDOW, KibaWindowClass))

typedef enum {
	KIBA_WINDOW_MAPPED = 1,
	KIBA_WINDOW_FOCUSED,
	KIBA_WINDOW_ICONIFIED,
	KIBA_WINDOW_MAXIMIZED,
	KIBA_WINDOW_URGENT,
	KIBA_WINDOW_UNMAPPED
}KibaWindowState;

struct _KibaWindow {
	GObject          parent_instance;
	
	GdkWindow       *gdk_window;
	Window           xwindow;
	KibaWindowState  state;
	char            *name;
};

struct _KibaWindowClass {
	GObjectClass parent_class;

	void (* icon_changed) (KibaWindow *window);
	void (* state_changed) (KibaWindow      *window,
				KibaWindowState  state);
	void (* name_changed) (KibaWindow  *window,
			       const gchar *name);
};

/**
 * Creates and returns a new KibaWindow object.
 *
 * @return The KibaWindow object created.
 */
KibaWindow* kiba_window_new (GdkWindow *gdk_window);

/**
 * Destroys and frees KibaWindow.
 *
 * @param window The KibaWindow.
 */
void kiba_window_destroy (KibaWindow *window);

G_END_DECLS

#endif

