/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_X11_H__
#define __KIBA_X11_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>
#include <X11/Xlib.h>

#include <kiba-types.h>

G_BEGIN_DECLS

/* returns a GList of GdkWindows */
GList* kiba_get_window_stack (Display *display);

/* returns the focussed window */
Window kiba_get_active_window (Display *display);

Atom kiba_get_atom (Display    *display,
		    const char *atom_name);

/* update _NET_WM_STRUT so that maximised windows doesnt overlap with the dock */
void kiba_set_wm_strut (Window     window,
			KibaStrut *strut);

void kiba_set_wm_blur (Window xwindow);

/***********
DESKTOP
***********/
/* returns TRUE if _NET_SHOWING_DESKTOP is set */
gboolean kiba_get_show_desktop (void);

/* toggles _NET_SHOWING_DESKTOP */
void kiba_toggle_showing_desktop (GtkWidget *widget,
				  gpointer   data);

char* kiba_get_active_workspace_name ();

/****************
WINDOW MANAGEMENT
****************/

void kiba_focus_window (GtkWidget *widget,
			gpointer   data);

void kiba_iconify_window (GtkWidget *widget,
			  gpointer   data);

void kiba_deiconify_window (GtkWidget *widget,
			    gpointer   data);

void kiba_unmaximize_window (GtkWidget *widget,
			     gpointer   data);

void kiba_maximize_window (GtkWidget  *widget,
			   gpointer    data);

void kiba_set_window_above (GtkWidget *widget,
			    gpointer   data);

void kiba_set_window_below (GtkWidget *widget,
			    gpointer   data);

void kiba_kill_window (GtkWidget  *widget,
		       gpointer    data);

void kiba_window_stick (GtkWidget *widget,
			gpointer   data);

/* returns the Icon from Window */
GdkPixbuf* kiba_get_icon (Window  window,
			  int     size);

/* checks if return data of _NET_WM_ICON is equal to old_icon */
gboolean kiba_icon_changed (Window  window,
			    Pixmap *icon_pixmap);

/* set icon geometry (for taskbar animation) */
void kiba_set_icon_geometry (Window xwindow,
			     int    x,
			     int    y,
			     int    width,
			     int    height);

char* kiba_get_wmclass (Display *display,
			Window   window);

gboolean kiba_window_urgency (Display   *display,
			      GdkWindow *window);

char* kiba_win_name (Display *display,
		     Window   window);

char* kiba_get_win_name (Display *display,
			 Window   xwindow);

char* kiba_get_wintype (Display   *display,
			GdkWindow *window);

/* returns current windowstate, -1=not running, 0=systray/not mapped, 1=shown, 3=iconified */
int kiba_get_winstate (Display   *display,
		       GdkWindow *window);

gboolean kiba_window_state_hint (GdkWindow  *window,
				 const char *state_hint);

/***
PIDs
***/
/* returns PID for given Window */
int kiba_get_win_pid (Display *display,
		      Window   window);

/* returns Window for the given pid or 0 if there is no window with this pid */
Window kiba_get_win_for_pid (int pid);

/*******
OPACITY
*******/
void kiba_change_opacity (Window  xwindow,
			  guint32 opacity);

int kiba_get_opacity (Window xwindow);

void kiba_set_opacity (GtkWidget *widget,
		       gpointer   data);

/*******
SATURATION
*******/
void kiba_change_saturation (Window  xwindow,
			     guint32 saturation);

int kiba_get_saturation (Window xwindow);

void kiba_set_saturation (GtkWidget *widget,
			  gpointer   data);

/*******
OPACITY
*******/
void kiba_change_brightness (Window  xwindow,
			     guint32 brightness);

int kiba_get_brightness (Window xwindow);

void kiba_set_brightness (GtkWidget *widget,
			  gpointer   data);

/*******
WORKSPACES
*******/
int kiba_get_active_workspace_number (Display *display);

int kiba_get_win_workspace_number (Display *display,
				   Window   window);

void kiba_activate_workspace (int new_active_space);

void kiba_window_set_workspace (GtkWidget *widget,
				gpointer   data);

void kiba_change_workspace (Window xwindow,
			    int    new_space);

void kiba_window_to_right_workspace (GtkWidget *widget,
				     gpointer   data);

void kiba_window_to_left_workspace (GtkWidget *widget,
				    gpointer   data);


/*******
VIEWPORTS
*******/
void kiba_get_num_viewports (int *x,
			     int *y);

void kiba_get_win_viewport_number (Window window,
				   int   *x,
				   int   *y);

void kiba_get_avtive_viewport (int *x,
			       int *y);

void kiba_change_win_viewport (Window xwindow,
			       int    x,
			       int    y);

void kiba_change_viewport (int x,
			   int y);

void kiba_window_change_workspace (GtkWidget *widget,
				   gpointer   data);

void kiba_window_to_right_viewport (GtkWidget *widget,
				    gpointer   data);

void kiba_window_to_left_viewport (GtkWidget *widget,
				   gpointer   data);

void kiba_window_change_viewport (GtkWidget *widget,
				  gpointer   data);

gboolean kiba_window_is_in_viewport (Window window,
				     int    viewport_x,
				     int    viewport_y);

void kiba_keyboard_move (GtkWidget *widget,
			 gpointer   data);

void kiba_keyboard_size (GtkWidget *widget,
			 gpointer data);

void kiba_move_window (GtkWidget *widget,
		       gpointer   data);

void kiba_resize_window (GtkWidget *widget,
			 gpointer   data);

/* loads a libwnck like right click menu in the given GtkMenu */
void kiba_load_app_menu (GdkWindow *window,
			 GtkMenu   *menu);

G_END_DECLS

#endif

